# ModmailTranslations

A python package to easily handle modmail-plugins i18n or something?

# Support

Support for this package is only provided on [Piyush's Discord Server](https://discord.gg/hWbb4Ee).

# Installation

* Add this to your `requirements.txt` in your plugin folder.

# Usage 

Example can be found in [examples folder](https://github.com/officialpiyush/modmailtranslation/tree/master/examples).